@@ -1,8 +1,4 @@
-use crate::{
-    arrayvec::ArrayVec,
-    defs::{LengthType, SpareMemoryPolicy},
-    errors::CapacityError,
-};
+use crate::{arrayvec::ArrayVec, errors::CapacityError, len::LengthType, mem::SpareMemoryPolicy};
 use core::{convert::TryFrom, mem, ptr};
 
 impl<T, L, SM, const C: usize> TryFrom<&[T]> for ArrayVec<T, L, SM, C>
@@ -72,11 +68,7 @@ where
 #[cfg(test)]
 mod testing {
     use crate as cds;
-    use cds::{
-        arrayvec::ArrayVec,
-        defs::{Uninitialized, Usize},
-        errors::CapacityError,
-    };
+    use cds::{arrayvec::ArrayVec, errors::CapacityError, len::Usize, mem::Uninitialized};
     type A = ArrayVec<u64, Usize, Uninitialized, 7>;
 
     #[test]
